# Basic command line commands to build and manage SCORM projects

## To install the package execute: 
sudo python setup.py install

### scobuild

This script automates the creation of a basic SCORM-compliant project structure and installs the `scoapi` npm package, a library to manage the SCORM API

## How to Use

1. **Run the Script**: Execute the Python script (`scobuild`).

2. **Enter Project Name**: When prompted, enter the desired name for your SCORM project.
